import os

DB_HOME = os.environ.get('HOME')
DB_DIR = f'{DB_HOME}/ofxdb'
